%define anolis_release 4
%define upstream_version %(echo %{version} | sed -e 's/\\./-/g')

Name: lm_sensors
Version: 3.6.0
Release: %{anolis_release}%{?dist}
Summary: Hardware monitoring tools
License: GPLv2+ and Verbatim and MIT
URL: http://github.com/lm-sensors/lm-sensors/

Source0: https://github.com/lm-sensors/lm-sensors/archive/V%{upstream_version}/lm-sensors-%{upstream_version}.tar.gz
Source1: lm_sensors.sysconfig
Source2: sensord.sysconfig
Source3: lm_sensors-modprobe-wrapper
Source4: lm_sensors-modprobe-r-wrapper
Source5: sensord.service
Source6: sensord-service-wrapper
Source7: lm_sensors.service
Source8: lm_sensors-wrapper

Patch0: 0001-Revert-unnecessary-soname-bump.patch

Patch1: 0001-Change-PIDFile-path-from-var-run-to-run.patch
Patch2: lm_sensors-3.6.0-allow_no_sensors.patch
Patch3: lm_sensors-3.6.0-sensors-detect-Add-support-for-AMD-CPU-Family-19h.patch

Requires: /usr/sbin/modprobe
%ifarch x86_64
Requires: /usr/sbin/dmidecode
%endif
Requires: lm_sensors-libs = %{version}-%{release}
Requires(post): systemd-units
BuildRequires: gcc make
BuildRequires: rrdtool-devel
BuildRequires: perl-generators
BuildRequires: kernel-headers >= 2.2.16, bison, flex, gawk


%description
lm_sensors is a free and open-source software tool that is used to monitor
the hardware health of a computer system. It is developed to work with Linux
operating systems and provides information about the system’s temperatures,
fan speeds, and voltage levels. The tool can be installed in any Linux distribu
tion and is compatible with a wide range of hardware sensors.

The lm_sensors tool interacts with the hardware sensors through the kernel
modules that are responsible for detecting and monitoring the sensors. The
modules communicate with the sensors and provide the information to lm_senso
rs, which then interprets the data and displays it to the user in a readable
format. The tool can be customized to display the information in different
formats, such as text, graph, or chart.

The lm_sensors tool can also be configured to trigger alerts when the system’s
hardware reaches critical levels. For example, it can be configured to send an
email or a notification when the system’s temperature exceeds a certain
threshold. This feature is particularly useful for server administrators who
need to monitor their systems’ health continuously.

%package libs
Summary: Lm_sensors core libraries
License: LGPLv2+

%description libs
Core libraries for lm_sensors applications


%package devel
Summary: Development files for programs which will use lm_sensors
Requires: lm_sensors-libs = %{version}-%{release}
# One manual page is licensed Verbatim (lib/libsensors.3). The rest is LGPLv2+.
License: LGPLv2+ and Verbatim

%description devel
The lm_sensors-devel package includes a header files and libraries for use
when building applications that make use of sensor data.


%package sensord
Summary: Daemon that periodically logs sensor readings
Requires: lm_sensors = %{version}-%{release}
Requires: lm_sensors-libs = %{version}-%{release}
# One man page is licensed Verbatim (prog/sensord/sensord.8). Files from
# dist-git are licensed MIT according to the FPCA. The rest is GPLv2+.
License: GPLv2+ and Verbatim and MIT

%description sensord
Daemon that periodically logs sensor readings to syslog or a round-robin
database, and warns of sensor alarms.

%package doc
Summary:        Documentation files for lm_sensors
Requires:       lm_sensors = %{version}-%{release}
BuildArch:      noarch

%description    doc
The lm_sensors-doc package contains documentation files for lm_sensors.


%prep
%autosetup -n lm-sensors-%{upstream_version} -p1

rm -f prog/init/sysconfig-lm_sensors-convert prog/hotplug/unhide_ICH_SMBus

mv prog/init/README prog/init/README.initscripts
chmod -x prog/init/fancontrol.init

cp -p %{SOURCE5} sensord.service
cp -p %{SOURCE7} lm_sensors.service
sed -i "s|\@WRAPPER_DIR\@|%{_libexecdir}/lm_sensors|" sensord.service
sed -i "s|\@WRAPPER_DIR\@|%{_libexecdir}/lm_sensors|" lm_sensors.service


%build
%set_build_flags
%{make_build} PREFIX=%{_prefix} LIBDIR=%{_libdir} MANDIR=%{_mandir} \
  EXLDFLAGS="$LDFLAGS" PROG_EXTRA=sensord BUILD_STATIC_LIB=0 user


%install
make PREFIX=%{_prefix} LIBDIR=%{_libdir} MANDIR=%{_mandir} PROG_EXTRA=sensord \
  DESTDIR=$RPM_BUILD_ROOT BUILD_STATIC_LIB=0 user_install

ln -s sensors.conf.5.gz $RPM_BUILD_ROOT%{_mandir}/man5/sensors3.conf.5.gz

mkdir -p $RPM_BUILD_ROOT%{_initrddir}
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/sensors.d
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig
install -pm 644 %{SOURCE1} $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/lm_sensors
install -pm 644 %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/sensord

mkdir -p $RPM_BUILD_ROOT%{_unitdir}
install -pm 644 prog/init/fancontrol.service $RPM_BUILD_ROOT%{_unitdir}
install -pm 644 lm_sensors.service           $RPM_BUILD_ROOT%{_unitdir}
install -pm 644 sensord.service              $RPM_BUILD_ROOT%{_unitdir}

mkdir -p $RPM_BUILD_ROOT%{_libexecdir}/lm_sensors
install -pm 755 %{SOURCE3} $RPM_BUILD_ROOT%{_libexecdir}/lm_sensors/lm_sensors-modprobe-wrapper
install -pm 755 %{SOURCE4} $RPM_BUILD_ROOT%{_libexecdir}/lm_sensors/lm_sensors-modprobe-r-wrapper
install -pm 755 %{SOURCE8} $RPM_BUILD_ROOT%{_libexecdir}/lm_sensors/lm_sensors-wrapper

install -pm 755 %{SOURCE6} $RPM_BUILD_ROOT%{_libexecdir}/lm_sensors/sensord-service-wrapper

%generate_compatibility_deps

%triggerun -- lm_sensors < 3.3.0-2
if [ -L /etc/rc3.d/S26lm_sensors ]; then
    /bin/systemctl enable lm_sensors.service >/dev/null 2>&1 || :
fi
/sbin/chkconfig --del lm_sensors


%post
%systemd_post lm_sensors.service

%post sensord
%systemd_post sensord.service

%preun
%systemd_preun lm_sensors.service

%preun sensord
%systemd_preun sensord.service

%postun
%systemd_postun_with_restart lm_sensors.service

%postun sensord
%systemd_postun_with_restart sensord.service

%files
%{_bindir}/*
%{_sbindir}/*
%{_mandir}/man1/*
%{_mandir}/man5/*
%{_mandir}/man8/*
%dir %{_libexecdir}/lm_sensors
%exclude %{_sbindir}/sensord
%dir %{_sysconfdir}/sensors.d
%{_unitdir}/fancontrol.service
%{_unitdir}/lm_sensors.service
%exclude %{_mandir}/man8/sensord.8.gz
%config %{_sysconfdir}/sensors3.conf
%{_libexecdir}/lm_sensors/lm_sensors-wrapper
%{_libexecdir}/lm_sensors/lm_sensors-modprobe*wrapper
%config(noreplace) %{_sysconfdir}/sysconfig/lm_sensors
%doc prog/init/fancontrol.init prog/init/README.initscripts
%{abidir}/*-option.list
%license COPYING

%files libs
%dir %{abidir}
%{_libdir}/*.so.*
%{abidir}/*.dump
%license COPYING.LGPL

%files devel
%{_mandir}/man3/*
%{_libdir}/lib*.so
%{_includedir}/sensors

%files sensord
%{_sbindir}/sensord
%doc prog/sensord/README
%{_unitdir}/sensord.service
%{_libexecdir}/lm_sensors/sensord-service-wrapper
%config(noreplace) %{_sysconfdir}/sysconfig/sensord

%files doc
%doc CHANGES CONTRIBUTORS doc README*


%changelog
* Fri Apr 14 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 3.6.0-4
- Optimize the spec

* Wed Nov 02 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.6.0-3
- optimise spec file

* Sat Oct 08 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.6.0-2
- add doc package

* Fri Jul 15 2022 happy_orange <songnannan@linux.alibaba.com> - 3.6.0-1
- Init pacakge from upstream
